# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKImageGradientPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkGradientMagnitudeRecursiveGaussianImageFilterPython
else:
    import _itkGradientMagnitudeRecursiveGaussianImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkInPlaceImageFilterAPython
import itk.itkImageToImageFilterAPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkPointPython
import itk.itkFixedArrayPython
import itk.pyBasePython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.vnl_matrixPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkVectorImagePython
import itk.itkImagePython
import itk.itkSizePython
import itk.itkRGBPixelPython
import itk.itkRGBAPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkImageRegionPython
import itk.itkVariableLengthVectorPython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkImageToImageFilterBPython

def itkGradientMagnitudeRecursiveGaussianImageFilterIF2IF2_New():
    return itkGradientMagnitudeRecursiveGaussianImageFilterIF2IF2.New()

class itkGradientMagnitudeRecursiveGaussianImageFilterIF2IF2(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF2IF2):
    r"""Proxy of C++ itkGradientMagnitudeRecursiveGaussianImageFilterIF2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGradientMagnitudeRecursiveGaussianImageFilterIF2IF2_Pointer"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIF2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGradientMagnitudeRecursiveGaussianImageFilterIF2IF2_Pointer"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIF2IF2_Clone(self)

    def SetSigma(self, sigma):
        r"""
        SetSigma(self, sigma)

        Parameters
        ----------
        sigma: double

        """
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIF2IF2_SetSigma(self, sigma)

    def GetSigma(self):
        r"""GetSigma(self) -> double"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIF2IF2_GetSigma(self)

    def SetNormalizeAcrossScale(self, normalize):
        r"""
        SetNormalizeAcrossScale(self, normalize)

        Parameters
        ----------
        normalize: bool

        """
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIF2IF2_SetNormalizeAcrossScale(self, normalize)

    def GetNormalizeAcrossScale(self):
        r"""GetNormalizeAcrossScale(self) -> bool"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIF2IF2_GetNormalizeAcrossScale(self)

    def NormalizeAcrossScaleOn(self):
        r"""NormalizeAcrossScaleOn(self)"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIF2IF2_NormalizeAcrossScaleOn(self)

    def NormalizeAcrossScaleOff(self):
        r"""NormalizeAcrossScaleOff(self)"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIF2IF2_NormalizeAcrossScaleOff(self)
    InputHasNumericTraitsCheck = _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIF2IF2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkGradientMagnitudeRecursiveGaussianImageFilterPython.delete_itkGradientMagnitudeRecursiveGaussianImageFilterIF2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGradientMagnitudeRecursiveGaussianImageFilterIF2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIF2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGradientMagnitudeRecursiveGaussianImageFilterIF2IF2

        Create a new object of the class itkGradientMagnitudeRecursiveGaussianImageFilterIF2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGradientMagnitudeRecursiveGaussianImageFilterIF2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGradientMagnitudeRecursiveGaussianImageFilterIF2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGradientMagnitudeRecursiveGaussianImageFilterIF2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGradientMagnitudeRecursiveGaussianImageFilterIF2IF2 in _itkGradientMagnitudeRecursiveGaussianImageFilterPython:
_itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIF2IF2_swigregister(itkGradientMagnitudeRecursiveGaussianImageFilterIF2IF2)

def itkGradientMagnitudeRecursiveGaussianImageFilterIF3IF3_New():
    return itkGradientMagnitudeRecursiveGaussianImageFilterIF3IF3.New()

class itkGradientMagnitudeRecursiveGaussianImageFilterIF3IF3(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIF3IF3):
    r"""Proxy of C++ itkGradientMagnitudeRecursiveGaussianImageFilterIF3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGradientMagnitudeRecursiveGaussianImageFilterIF3IF3_Pointer"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIF3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGradientMagnitudeRecursiveGaussianImageFilterIF3IF3_Pointer"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIF3IF3_Clone(self)

    def SetSigma(self, sigma):
        r"""
        SetSigma(self, sigma)

        Parameters
        ----------
        sigma: double

        """
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIF3IF3_SetSigma(self, sigma)

    def GetSigma(self):
        r"""GetSigma(self) -> double"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIF3IF3_GetSigma(self)

    def SetNormalizeAcrossScale(self, normalize):
        r"""
        SetNormalizeAcrossScale(self, normalize)

        Parameters
        ----------
        normalize: bool

        """
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIF3IF3_SetNormalizeAcrossScale(self, normalize)

    def GetNormalizeAcrossScale(self):
        r"""GetNormalizeAcrossScale(self) -> bool"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIF3IF3_GetNormalizeAcrossScale(self)

    def NormalizeAcrossScaleOn(self):
        r"""NormalizeAcrossScaleOn(self)"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIF3IF3_NormalizeAcrossScaleOn(self)

    def NormalizeAcrossScaleOff(self):
        r"""NormalizeAcrossScaleOff(self)"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIF3IF3_NormalizeAcrossScaleOff(self)
    InputHasNumericTraitsCheck = _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIF3IF3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkGradientMagnitudeRecursiveGaussianImageFilterPython.delete_itkGradientMagnitudeRecursiveGaussianImageFilterIF3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGradientMagnitudeRecursiveGaussianImageFilterIF3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIF3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGradientMagnitudeRecursiveGaussianImageFilterIF3IF3

        Create a new object of the class itkGradientMagnitudeRecursiveGaussianImageFilterIF3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGradientMagnitudeRecursiveGaussianImageFilterIF3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGradientMagnitudeRecursiveGaussianImageFilterIF3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGradientMagnitudeRecursiveGaussianImageFilterIF3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGradientMagnitudeRecursiveGaussianImageFilterIF3IF3 in _itkGradientMagnitudeRecursiveGaussianImageFilterPython:
_itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIF3IF3_swigregister(itkGradientMagnitudeRecursiveGaussianImageFilterIF3IF3)

def itkGradientMagnitudeRecursiveGaussianImageFilterISS2ISS2_New():
    return itkGradientMagnitudeRecursiveGaussianImageFilterISS2ISS2.New()

class itkGradientMagnitudeRecursiveGaussianImageFilterISS2ISS2(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS2ISS2):
    r"""Proxy of C++ itkGradientMagnitudeRecursiveGaussianImageFilterISS2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGradientMagnitudeRecursiveGaussianImageFilterISS2ISS2_Pointer"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterISS2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGradientMagnitudeRecursiveGaussianImageFilterISS2ISS2_Pointer"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterISS2ISS2_Clone(self)

    def SetSigma(self, sigma):
        r"""
        SetSigma(self, sigma)

        Parameters
        ----------
        sigma: double

        """
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterISS2ISS2_SetSigma(self, sigma)

    def GetSigma(self):
        r"""GetSigma(self) -> double"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterISS2ISS2_GetSigma(self)

    def SetNormalizeAcrossScale(self, normalize):
        r"""
        SetNormalizeAcrossScale(self, normalize)

        Parameters
        ----------
        normalize: bool

        """
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterISS2ISS2_SetNormalizeAcrossScale(self, normalize)

    def GetNormalizeAcrossScale(self):
        r"""GetNormalizeAcrossScale(self) -> bool"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterISS2ISS2_GetNormalizeAcrossScale(self)

    def NormalizeAcrossScaleOn(self):
        r"""NormalizeAcrossScaleOn(self)"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterISS2ISS2_NormalizeAcrossScaleOn(self)

    def NormalizeAcrossScaleOff(self):
        r"""NormalizeAcrossScaleOff(self)"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterISS2ISS2_NormalizeAcrossScaleOff(self)
    InputHasNumericTraitsCheck = _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterISS2ISS2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkGradientMagnitudeRecursiveGaussianImageFilterPython.delete_itkGradientMagnitudeRecursiveGaussianImageFilterISS2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGradientMagnitudeRecursiveGaussianImageFilterISS2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterISS2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGradientMagnitudeRecursiveGaussianImageFilterISS2ISS2

        Create a new object of the class itkGradientMagnitudeRecursiveGaussianImageFilterISS2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGradientMagnitudeRecursiveGaussianImageFilterISS2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGradientMagnitudeRecursiveGaussianImageFilterISS2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGradientMagnitudeRecursiveGaussianImageFilterISS2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGradientMagnitudeRecursiveGaussianImageFilterISS2ISS2 in _itkGradientMagnitudeRecursiveGaussianImageFilterPython:
_itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterISS2ISS2_swigregister(itkGradientMagnitudeRecursiveGaussianImageFilterISS2ISS2)

def itkGradientMagnitudeRecursiveGaussianImageFilterISS3ISS3_New():
    return itkGradientMagnitudeRecursiveGaussianImageFilterISS3ISS3.New()

class itkGradientMagnitudeRecursiveGaussianImageFilterISS3ISS3(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterISS3ISS3):
    r"""Proxy of C++ itkGradientMagnitudeRecursiveGaussianImageFilterISS3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGradientMagnitudeRecursiveGaussianImageFilterISS3ISS3_Pointer"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterISS3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGradientMagnitudeRecursiveGaussianImageFilterISS3ISS3_Pointer"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterISS3ISS3_Clone(self)

    def SetSigma(self, sigma):
        r"""
        SetSigma(self, sigma)

        Parameters
        ----------
        sigma: double

        """
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterISS3ISS3_SetSigma(self, sigma)

    def GetSigma(self):
        r"""GetSigma(self) -> double"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterISS3ISS3_GetSigma(self)

    def SetNormalizeAcrossScale(self, normalize):
        r"""
        SetNormalizeAcrossScale(self, normalize)

        Parameters
        ----------
        normalize: bool

        """
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterISS3ISS3_SetNormalizeAcrossScale(self, normalize)

    def GetNormalizeAcrossScale(self):
        r"""GetNormalizeAcrossScale(self) -> bool"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterISS3ISS3_GetNormalizeAcrossScale(self)

    def NormalizeAcrossScaleOn(self):
        r"""NormalizeAcrossScaleOn(self)"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterISS3ISS3_NormalizeAcrossScaleOn(self)

    def NormalizeAcrossScaleOff(self):
        r"""NormalizeAcrossScaleOff(self)"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterISS3ISS3_NormalizeAcrossScaleOff(self)
    InputHasNumericTraitsCheck = _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterISS3ISS3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkGradientMagnitudeRecursiveGaussianImageFilterPython.delete_itkGradientMagnitudeRecursiveGaussianImageFilterISS3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGradientMagnitudeRecursiveGaussianImageFilterISS3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterISS3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGradientMagnitudeRecursiveGaussianImageFilterISS3ISS3

        Create a new object of the class itkGradientMagnitudeRecursiveGaussianImageFilterISS3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGradientMagnitudeRecursiveGaussianImageFilterISS3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGradientMagnitudeRecursiveGaussianImageFilterISS3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGradientMagnitudeRecursiveGaussianImageFilterISS3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGradientMagnitudeRecursiveGaussianImageFilterISS3ISS3 in _itkGradientMagnitudeRecursiveGaussianImageFilterPython:
_itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterISS3ISS3_swigregister(itkGradientMagnitudeRecursiveGaussianImageFilterISS3ISS3)

def itkGradientMagnitudeRecursiveGaussianImageFilterIUC2IUC2_New():
    return itkGradientMagnitudeRecursiveGaussianImageFilterIUC2IUC2.New()

class itkGradientMagnitudeRecursiveGaussianImageFilterIUC2IUC2(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIUC2IUC2):
    r"""Proxy of C++ itkGradientMagnitudeRecursiveGaussianImageFilterIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGradientMagnitudeRecursiveGaussianImageFilterIUC2IUC2_Pointer"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGradientMagnitudeRecursiveGaussianImageFilterIUC2IUC2_Pointer"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIUC2IUC2_Clone(self)

    def SetSigma(self, sigma):
        r"""
        SetSigma(self, sigma)

        Parameters
        ----------
        sigma: double

        """
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIUC2IUC2_SetSigma(self, sigma)

    def GetSigma(self):
        r"""GetSigma(self) -> double"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIUC2IUC2_GetSigma(self)

    def SetNormalizeAcrossScale(self, normalize):
        r"""
        SetNormalizeAcrossScale(self, normalize)

        Parameters
        ----------
        normalize: bool

        """
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIUC2IUC2_SetNormalizeAcrossScale(self, normalize)

    def GetNormalizeAcrossScale(self):
        r"""GetNormalizeAcrossScale(self) -> bool"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIUC2IUC2_GetNormalizeAcrossScale(self)

    def NormalizeAcrossScaleOn(self):
        r"""NormalizeAcrossScaleOn(self)"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIUC2IUC2_NormalizeAcrossScaleOn(self)

    def NormalizeAcrossScaleOff(self):
        r"""NormalizeAcrossScaleOff(self)"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIUC2IUC2_NormalizeAcrossScaleOff(self)
    InputHasNumericTraitsCheck = _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIUC2IUC2_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkGradientMagnitudeRecursiveGaussianImageFilterPython.delete_itkGradientMagnitudeRecursiveGaussianImageFilterIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGradientMagnitudeRecursiveGaussianImageFilterIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGradientMagnitudeRecursiveGaussianImageFilterIUC2IUC2

        Create a new object of the class itkGradientMagnitudeRecursiveGaussianImageFilterIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGradientMagnitudeRecursiveGaussianImageFilterIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGradientMagnitudeRecursiveGaussianImageFilterIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGradientMagnitudeRecursiveGaussianImageFilterIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGradientMagnitudeRecursiveGaussianImageFilterIUC2IUC2 in _itkGradientMagnitudeRecursiveGaussianImageFilterPython:
_itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIUC2IUC2_swigregister(itkGradientMagnitudeRecursiveGaussianImageFilterIUC2IUC2)

def itkGradientMagnitudeRecursiveGaussianImageFilterIUC3IUC3_New():
    return itkGradientMagnitudeRecursiveGaussianImageFilterIUC3IUC3.New()

class itkGradientMagnitudeRecursiveGaussianImageFilterIUC3IUC3(itk.itkInPlaceImageFilterAPython.itkInPlaceImageFilterIUC3IUC3):
    r"""Proxy of C++ itkGradientMagnitudeRecursiveGaussianImageFilterIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGradientMagnitudeRecursiveGaussianImageFilterIUC3IUC3_Pointer"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGradientMagnitudeRecursiveGaussianImageFilterIUC3IUC3_Pointer"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIUC3IUC3_Clone(self)

    def SetSigma(self, sigma):
        r"""
        SetSigma(self, sigma)

        Parameters
        ----------
        sigma: double

        """
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIUC3IUC3_SetSigma(self, sigma)

    def GetSigma(self):
        r"""GetSigma(self) -> double"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIUC3IUC3_GetSigma(self)

    def SetNormalizeAcrossScale(self, normalize):
        r"""
        SetNormalizeAcrossScale(self, normalize)

        Parameters
        ----------
        normalize: bool

        """
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIUC3IUC3_SetNormalizeAcrossScale(self, normalize)

    def GetNormalizeAcrossScale(self):
        r"""GetNormalizeAcrossScale(self) -> bool"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIUC3IUC3_GetNormalizeAcrossScale(self)

    def NormalizeAcrossScaleOn(self):
        r"""NormalizeAcrossScaleOn(self)"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIUC3IUC3_NormalizeAcrossScaleOn(self)

    def NormalizeAcrossScaleOff(self):
        r"""NormalizeAcrossScaleOff(self)"""
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIUC3IUC3_NormalizeAcrossScaleOff(self)
    InputHasNumericTraitsCheck = _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIUC3IUC3_InputHasNumericTraitsCheck
    
    __swig_destroy__ = _itkGradientMagnitudeRecursiveGaussianImageFilterPython.delete_itkGradientMagnitudeRecursiveGaussianImageFilterIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGradientMagnitudeRecursiveGaussianImageFilterIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGradientMagnitudeRecursiveGaussianImageFilterIUC3IUC3

        Create a new object of the class itkGradientMagnitudeRecursiveGaussianImageFilterIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGradientMagnitudeRecursiveGaussianImageFilterIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGradientMagnitudeRecursiveGaussianImageFilterIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGradientMagnitudeRecursiveGaussianImageFilterIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGradientMagnitudeRecursiveGaussianImageFilterIUC3IUC3 in _itkGradientMagnitudeRecursiveGaussianImageFilterPython:
_itkGradientMagnitudeRecursiveGaussianImageFilterPython.itkGradientMagnitudeRecursiveGaussianImageFilterIUC3IUC3_swigregister(itkGradientMagnitudeRecursiveGaussianImageFilterIUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def gradient_magnitude_recursive_gaussian_image_filter(*args: itkt.ImageLike,  sigma: float=..., normalize_across_scale: bool=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for GradientMagnitudeRecursiveGaussianImageFilter"""
    import itk

    kwarg_typehints = { 'sigma':sigma,'normalize_across_scale':normalize_across_scale }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.GradientMagnitudeRecursiveGaussianImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def gradient_magnitude_recursive_gaussian_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKImageGradient.GradientMagnitudeRecursiveGaussianImageFilter
    gradient_magnitude_recursive_gaussian_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    gradient_magnitude_recursive_gaussian_image_filter.__doc__ = filter_object.__doc__



